@@ -1,4 +1,3 @@
-
 #define MAX_TAGNAMELENGTH 20
 #define MAX_STRIPTAGS 20
 
@@ -26,11 +25,18 @@ typedef struct Stripper {
   char o_striptags[MAX_STRIPTAGS][MAX_TAGNAMELENGTH];
   int numstriptags;
   int o_emit_spaces;
+  int o_emit_newlines;
   int o_decode_entities;
+
+  int o_auto_reset;
+
+  int o_debug;
 } Stripper;
 
-void strip_html( Stripper * stripper, const char * raw, char * clean );
-void reset( Stripper * stripper );
+void _strip_html( Stripper * stripper, char * raw, char * clean, int is_utf8_p );
+static int utf8_char_width( unsigned char * string );
+void _reset( Stripper * stripper );
+
 void clear_striptags( Stripper * stripper );
 void add_striptag( Stripper * stripper, char * tag );
 
